| MultiConservationProblem-class | R Documentation |
This class is used to represent multi-objective conservation planning
problems. It stores the data (e.g., planning units, and features) and
mathematical formulation (e.g., the objective, constraints,
and other design criteria) needed to generate prioritizations.
Most users should use multi_problem() to generate new
multi-objective conservation problem objects, and the functions distributed
with the package to interact
with them (e.g., number_of_features(), number_of_planning_units()).
Only experts should use the fields and methods for this class directly.
problemslist containing ConservationProblem objects.
defaultslist indicating if other fields contain defaults.
approachMultiObjApproach object
for specifying the multi-objective optimization approach.
solverSolver object specifying the solver for
generating solutions.
MultiConservationProblem$convert_total_unit_ids_to_indices()
MultiConservationProblem$planning_unit_indices_with_finite_costs()
MultiConservationProblem$new()Create a new multi-objective conservation problem object.
MultiConservationProblem$new(problems)
problemslist containing ConservationProblem objects.
A new MultiConservationProblem object.
MultiConservationProblem$summary()Print extended information about the object.
MultiConservationProblem$summary()
Invisible TRUE.
MultiConservationProblem$print()Print concise information about the object.
MultiConservationProblem$print()
Invisible TRUE.
MultiConservationProblem$show()Display concise information about the object.
MultiConservationProblem$show()
Invisible TRUE.
MultiConservationProblem$repr()Generate a character representation of the object.
MultiConservationProblem$repr()
A character value.
MultiConservationProblem$number_of_planning_units()Obtain the number of planning units. The planning units correspond to
elements in the cost data
(e.g., indices, rows, geometries, cells) that have finite
values in at least one zone. In other words, planning unit are
elements in the cost data that do not have missing (NA) values in
every zone.
MultiConservationProblem$number_of_planning_units()
An integer value.
MultiConservationProblem$is_ids_equivalent_to_indices()Check if planning unit identifiers are equivalent to the planning
unit indices? Only FALSE if the planning units are
data.frame format.
MultiConservationProblem$is_ids_equivalent_to_indices()
A logical value.
MultiConservationProblem$planning_unit_indices()Obtain the planning unit indices.
MultiConservationProblem$planning_unit_indices()
An integer vector.
MultiConservationProblem$total_unit_ids()Obtain the total unit identifiers.
MultiConservationProblem$total_unit_ids()
An integer vector.
MultiConservationProblem$convert_total_unit_ids_to_indices()Convert total unit identifiers to indices.
MultiConservationProblem$convert_total_unit_ids_to_indices(ids)
idsinteger vector with planning unit identifiers.
An integer vector.
MultiConservationProblem$planning_unit_indices_with_finite_costs()Obtain the planning unit indices that are associated with finite cost values.
MultiConservationProblem$planning_unit_indices_with_finite_costs()
A list of integer vectors. Each list element corresponds to
a different zone.
MultiConservationProblem$number_of_total_units()Obtain the number of total units. The total units include all elements
in the cost data
(e.g., indices, rows, geometries, cells), including those with
missing (NA) values.
MultiConservationProblem$number_of_total_units()
An integer value.
MultiConservationProblem$planning_unit_class()Get planning unit class.
MultiConservationProblem$planning_unit_class()
A character value.
MultiConservationProblem$number_of_features()Obtain the number of features.
MultiConservationProblem$number_of_features()
An integer value.
MultiConservationProblem$feature_names()Obtain the names of the features.
MultiConservationProblem$feature_names()
A character vector.
MultiConservationProblem$number_of_problems()Obtain the number of problems.
MultiConservationProblem$number_of_problems()
An integer value.
MultiConservationProblem$problem_names()Obtain the names of the problems.
MultiConservationProblem$problem_names()
A character vector.
MultiConservationProblem$number_of_zones()Obtain the number of zones.
MultiConservationProblem$number_of_zones()
An integer value.
MultiConservationProblem$zone_names()Obtain the zone names.
MultiConservationProblem$zone_names()
A character vector.
MultiConservationProblem$add_approach()Create a new object with an approach added to the problem formulation.
MultiConservationProblem$add_approach(x)
xMultiObjApproach object.
An updated MultiConservationProblem object.
MultiConservationProblem$add_solver()Create a new object with a solver added to the problem formulation.
MultiConservationProblem$add_solver(x)
xSolver object.
An updated MultiConservationProblem object.
MultiConservationProblem$clone()The objects of this class are cloneable with this method.
MultiConservationProblem$clone(deep = FALSE)
deepWhether to make a deep clone.
Other classes:
ConservationModifier-class,
ConservationProblem-class,
Constraint-class,
Decision-class,
MultiObjApproach-class,
Objective-class,
OptimizationProblem-class,
Penalty-class,
Portfolio-class,
Solver-class,
Target-class,
TargetMethod-class,
Weight-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.