View source: R/add_cbc_solver.R
| add_cbc_solver | R Documentation |
Specify that the CBC (COIN-OR branch and cut) software should be used to solve a conservation planning problem (Forrest & Lougee-Heimer 2005). This function can also be used to customize the behavior of the solver. It requires the rcbc package to be installed (only available on GitHub, see below for installation instructions).
add_cbc_solver(
x,
gap = 0.1,
time_limit = .Machine$integer.max,
presolve = 2,
threads = 1,
first_feasible = FALSE,
start_solution = NULL,
verbose = TRUE,
control = list()
)
x |
|
gap |
|
time_limit |
|
presolve |
|
threads |
|
first_feasible |
|
start_solution |
|
verbose |
|
control |
|
CBC is an
open-source mixed integer programming solver that is part of the
Computational Infrastructure for Operations Research (COIN-OR) project.
This solver seems to have much better performance than the other open-source
solvers (i.e., add_highs_solver(), add_rsymphony_solver(),
add_lpsymphony_solver())
(see the Solver benchmarks vignette for details).
As such, it is strongly recommended to use this solver if the Gurobi and
IBM CPLEX solvers are not available.
An updated problem() or multi_problem() object with the solver added to
it.
The rcbc package is required to use this solver. Since the rcbc package is not available on the the Comprehensive R Archive Network (CRAN), it must be installed from its GitHub repository. To install the rcbc package, please use the following code:
if (!require(remotes)) install.packages("remotes")
remotes::install_github("dirkschumacher/rcbc")
Note that you may also need to install several dependencies – such as the Rtools software or system libraries – prior to installing the rcbc package. For further details on installing this package, please consult the online package documentation.
Broadly speaking, start_solution must be in the same
format as the planning unit data in x.
Further details on the correct format are described below.
x has numeric planning unitsHere start_solution must be a
numeric vector with each element corresponding to a different planning
unit. It should have the same number of planning units as those
in x. Additionally, any planning units with missing
cost (NA) values should also have missing (NA) values in the
start_solution.
x has matrix planning unitsHere start_solution must be a
matrix vector with each row corresponding to a different planning
unit, and each column correspond to a different management zone.
It should have the same number of planning units and zones
as those in x. Additionally, any planning units with
missing cost (NA) values for a particular zone should also have a
missing (NA) values in start_solution.
x has terra::rast() planning unitsHere start_solution
be a terra::rast() object where different cells correspond
to different planning units and layers correspond to
a different management zones. It should have the same dimensionality
(rows, columns, layers), resolution, extent, and coordinate reference
system as the planning units in x. Additionally,
any planning units with missing cost (NA) values for a particular zone
should also have missing (NA) values in start_solution.
x has data.frame planning unitsHere start_solution must
be a data.frame with each column corresponding to a different zone,
each row corresponding to a different planning unit, and cell values
corresponding to the solution value. This means that if a data.frame
object containing the solution also contains additional columns, then
these columns will need to be subsetted prior to using this function
(see below for example with sf::sf() data).
Additionally, any planning units with missing cost
(NA) values for a particular zone should also have missing (NA)
values in start_solution.
x has sf::sf() planning unitsHere start_solution must be
a sf::sf() object with each column corresponding to a different
zone, each row corresponding to a different planning unit, and cell values
corresponding to the solution value. This means that if the
sf::sf() object containing the solution also contains additional
columns, then these columns will need to be subsetted prior to using this
function (see below for example).
Additionally, start_solution must also have the same
coordinate reference system as the planning unit data.
Furthermore, any planning units with missing cost
(NA) values for a particular zone should also have missing (NA)
values in start_solution.
Forrest J and Lougee-Heimer R (2005) CBC User Guide. In Emerging theory, Methods, and Applications (pp. 257–277). INFORMS, Catonsville, MD. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1287/educ.1053.0020")}.
Other functions for adding solvers:
add_cplex_solver(),
add_default_solver(),
add_gurobi_solver(),
add_highs_solver(),
add_lsymphony_solver,
add_rsymphony_solver()
# load data
sim_pu_raster <- get_sim_pu_raster()
sim_features <- get_sim_features()
# create problem
p1 <-
problem(sim_pu_raster, sim_features) %>%
add_min_set_objective() %>%
add_relative_targets(0.1) %>%
add_binary_decisions() %>%
add_cbc_solver(gap = 0, verbose = FALSE)
# generate solution %>%
s1 <- solve(p1)
# plot solution
plot(s1, main = "solution", axes = FALSE)
# create a similar problem with boundary length penalties and
# specify the solution from the previous run as a starting solution
p2 <-
problem(sim_pu_raster, sim_features) %>%
add_min_set_objective() %>%
add_relative_targets(0.1) %>%
add_boundary_penalties(10) %>%
add_binary_decisions() %>%
add_cbc_solver(gap = 0, start_solution = s1, verbose = FALSE)
# generate solution
s2 <- solve(p2)
# plot solution
plot(s2, main = "solution with boundary penalties", axes = FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.