category_layer: Category layer

View source: R/category_layer.R

category_layerR Documentation

Category layer

Description

Convert a multi-layer terra::rast() object into a single-layer terra::rast() object where pixel values indicate which input layer had the greatest value.

Usage

category_layer(x)

Arguments

x

terra::rast() object containing multiple layers.

Details

This function is provided to help manage data that encompass multiple management zones. For instance, this function may be helpful for interpreting solutions for problems associated with multiple zones that have binary decisions. It is essentially a wrapper for terra::which.max().

Value

A terra::rast() object.

See Also

The binary_stack() function performs the reverse of this function.

Examples


# create a binary raster stack
x <- terra::rast(list(
 terra::rast(matrix(c(1, 0, 0, 1, NA, 0), nrow = 3)),
 terra::rast(matrix(c(0, 1, 0, 0, NA, 0), nrow = 3)),
 terra::rast(matrix(c(0, 0, 1, 0, NA, 1), nrow = 3))
))

# plot data
plot(x)

# convert to category layer
y <- category_layer(x)

# plot result
plot(y)


prioritizr documentation built on Sept. 24, 2026, 5:07 p.m.