View source: R/eval_feature_representation_summary.R
| eval_feature_representation_summary | R Documentation |
Calculate how well features are represented by a solution to a conservation planning problem. These summary statistics are reported for each and every feature, and each and every zone, within a conservation planning problem.
eval_feature_representation_summary(x, solution)
## S3 method for class 'ConservationProblem'
eval_feature_representation_summary(x, solution)
## S3 method for class 'MultiConservationProblem'
eval_feature_representation_summary(x, solution)
x |
|
solution |
|
A tibble::tibble() object describing feature representation by the
solution.
Here, each row describes a specific summary statistic
(e.g., different management zone) for a specific feature.
It contains the following columns.
character name of problem. Note that this column
is only present if x is a multi_problem() object.
character description of the summary statistic.
The statistics associated with the "overall" value
in this column are calculated using all planning unit values.
If x has multiple management zones, this means
that all calculations are completed by summing together
all planning unit values across all zones. For example, if there are
two zones, a single planning unit, and a feature has a value of one
in the single planning unit for both zones, then total_amount will
contain a value of two (even though it would not be possible to
to achieve a value of two because the planning unit could not
simultaneously be allocated to both zones).
Additionally, if x has multiple management zones,
then summary statistics are also provided for each zone separately
(indicated using zone names).
character name of the feature.
numeric total amount of each feature available
in the entire conservation planning problem
(not just planning units selected within the solution).
It is calculated as the sum of the feature data,
supplied when creating a problem() object
(e.g., presence/absence values).
numeric total amount of each feature secured within
the solution. It is calculated as the sum of the feature data,
supplied when creating a problem() object
(e.g., presence/absence values), weighted by the status of each
planning unit in the solution (e.g., selected or not for
prioritization).
numeric proportion of each feature secured within the solution. It is
calculated by dividing values in the "absolute_held" column by those in the
"total_amount" column.
Broadly speaking, solution must be in the same format as
the planning unit data in x.
Further details on the correct format are listed separately
for each of the different planning unit data formats.
x has numeric planning unitsHere solution must be a
numeric vector with each element corresponding to a different planning
unit. It should have the same number of planning units as those
in x. Additionally, any planning units with missing
cost (NA) values should also have missing (NA) values in the
solution.
x has matrix planning unitsHere solution must be a
matrix vector with each row corresponding to a different planning
unit, and each column correspond to a different management zone.
It should have the same number of planning units and zones
as those in x. Additionally, any planning units with
missing cost (NA) values for a particular zone should also have a
missing (NA) values in solution.
x has terra::rast() planning unitsHere solution
be a terra::rast() object where different cells correspond
to different planning units and layers correspond to
a different management zones. It should have the same dimensionality
(rows, columns, layers), resolution, extent, and coordinate reference
system as the planning units in x. Additionally,
any planning units with missing cost (NA) values for a particular zone
should also have missing (NA) values in solution.
x has data.frame planning unitsHere solution must
be a data.frame with each column corresponding to a different zone,
each row corresponding to a different planning unit, and cell values
corresponding to the solution value. This means that if a data.frame
object containing the solution also contains additional columns, then
these columns will need to be subsetted prior to using this function
(see below for example with sf::sf() data).
Additionally, any planning units with missing cost
(NA) values for a particular zone should also have missing (NA)
values in solution.
x has sf::sf() planning unitsHere solution must be
a sf::sf() object with each column corresponding to a different
zone, each row corresponding to a different planning unit, and cell values
corresponding to the solution value. This means that if the
sf::sf() object containing the solution also contains additional
columns, then these columns will need to be subsetted prior to using this
function (see below for example).
Additionally, solution must also have the same
coordinate reference system as the planning unit data.
Furthermore, any planning units with missing cost
(NA) values for a particular zone should also have missing (NA)
values in solution.
See summaries for an overview of all functions for summarizing solutions.
Other functions for summarizing solutions:
eval_asym_connectivity_summary(),
eval_boundary_summary(),
eval_connectivity_summary(),
eval_cost_summary(),
eval_n_summary(),
eval_objective_summary(),
eval_target_coverage_summary()
# set seed for reproducibility
set.seed(500)
# load data
sim_pu_raster <- get_sim_pu_raster()
sim_pu_polygons <- get_sim_pu_polygons()
sim_features <- get_sim_features()
sim_zones_pu_raster <- get_sim_zones_pu_raster()
sim_zones_pu_polygons <- get_sim_zones_pu_polygons()
sim_zones_features <- get_sim_zones_features()
# create a simple conservation planning dataset so we can see exactly
# how feature representation is calculated
pu <- data.frame(
id = seq_len(10),
cost = c(0.2, NA, runif(8)),
spp1 = runif(10),
spp2 = c(rpois(9, 4), NA)
)
# create problem
p1 <-
problem(pu, c("spp1", "spp2"), cost_column = "cost") %>%
add_min_set_objective() %>%
add_relative_targets(0.1) %>%
add_binary_decisions() %>%
add_default_solver(verbose = FALSE)
# create a solution
# specifically, a data.frame with a single column that contains
# binary values indicating if each planning units was selected or not
s1 <- data.frame(s = c(1, NA, rep(c(1, 0), 4)))
print(s1)
# calculate feature representation
r1 <- eval_feature_representation_summary(p1, s1)
print(r1)
# let's verify that feature representation calculations are correct
# by manually performing the calculations and compare the results with r1
## calculate total amount for each feature
print(
setNames(
c(sum(pu$spp1, na.rm = TRUE), sum(pu$spp2, na.rm = TRUE)),
c("spp1", "spp2")
)
)
## calculate absolute amount held for each feature
print(
setNames(
c(sum(pu$spp1 * s1$s, na.rm = TRUE), sum(pu$spp2 * s1$s, na.rm = TRUE)),
c("spp1", "spp2")
)
)
## calculate relative amount held for each feature
print(
setNames(
c(
sum(pu$spp1 * s1$s, na.rm = TRUE) / sum(pu$spp1, na.rm = TRUE),
sum(pu$spp2 * s1$s, na.rm = TRUE) / sum(pu$spp2, na.rm = TRUE)
),
c("spp1", "spp2")
)
)
# solve problem using an exact algorithm solver
s1_2 <- solve(p1)
print(s1_2)
# calculate feature representation in this solution
r1_2 <- eval_feature_representation_summary(
p1, s1_2[, "solution_1", drop = FALSE]
)
print(r1_2)
# build minimal conservation problem with raster data
p2 <-
problem(sim_pu_raster, sim_features) %>%
add_min_set_objective() %>%
add_relative_targets(0.1) %>%
add_binary_decisions() %>%
add_default_solver(verbose = FALSE)
# solve problem
s2 <- solve(p2)
# print solution
print(s2)
# calculate feature representation in the solution
r2 <- eval_feature_representation_summary(p2, s2)
print(r2)
# plot solution
plot(s2, main = "solution", axes = FALSE)
# build minimal conservation problem with polygon data
p3 <-
problem(sim_pu_polygons, sim_features, cost_column = "cost") %>%
add_min_set_objective() %>%
add_relative_targets(0.1) %>%
add_binary_decisions() %>%
add_default_solver(verbose = FALSE)
# solve problem
s3 <- solve(p3)
# print first six rows of the attribute table
print(head(s3))
# calculate feature representation in the solution
r3 <- eval_feature_representation_summary(p3, s3[, "solution_1"])
print(r3)
# plot solution
plot(s3[, "solution_1"], main = "solution", axes = FALSE)
# build multi-zone conservation problem with raster data
p4 <-
problem(sim_zones_pu_raster, sim_zones_features) %>%
add_min_set_objective() %>%
add_relative_targets(matrix(runif(15, 0.1, 0.2), nrow = 5, ncol = 3)) %>%
add_binary_decisions() %>%
add_default_solver(verbose = FALSE)
# solve problem
s4 <- solve(p4)
# print solution
print(s4)
# calculate feature representation in the solution
r4 <- eval_feature_representation_summary(p4, s4)
print(r4)
# plot solution
plot(category_layer(s4), main = "solution", axes = FALSE)
# build multi-zone conservation problem with polygon data
p5 <-
problem(
sim_zones_pu_polygons, sim_zones_features,
cost_column = c("cost_1", "cost_2", "cost_3")
) %>%
add_min_set_objective() %>%
add_relative_targets(matrix(runif(15, 0.1, 0.2), nrow = 5, ncol = 3)) %>%
add_binary_decisions() %>%
add_default_solver(verbose = FALSE)
# solve problem
s5 <- solve(p5)
# print first six rows of the attribute table
print(head(s5))
# calculate feature representation in the solution
r5 <- eval_feature_representation_summary(
p5, s5[, c("solution_1_zone_1", "solution_1_zone_2", "solution_1_zone_3")]
)
print(r5)
# create new column representing the zone id that each planning unit
# was allocated to in the solution
s5$solution <- category_vector(
s5[, c("solution_1_zone_1", "solution_1_zone_2", "solution_1_zone_3")]
)
s5$solution <- factor(s5$solution)
# plot solution
plot(s5[, "solution"])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.