View source: R/eval_rare_richness_importance.R
| eval_rare_richness_importance | R Documentation |
Calculate importance scores for planning units selected in a solution using rarity weighted richness scores (based on Williams et al. 1996).
eval_rare_richness_importance(x, solution, rescale = TRUE)
x |
|
solution |
|
rescale |
|
Rarity weighted richness scores are calculated using the following
terms. Let I denote the set of planning units (indexed by
i), let J denote the set of conservation features (indexed by
j), let r_{ij} denote the amount of feature j
associated with planning unit i, and let m_j denote the
maximum value of feature j in r_{ij} in all planning units
i \in I. Given these terms, rarity weighted richness for
planning unit k is calculated as follows:
\mathit{RWR}_{k} = \sum_{j}^{J}
\frac{ \frac{r_{ik}}{m_j} }{\sum_{i}^{I}r_{ij}}
This method is only recommended for large-scaled conservation planning exercises (i.e., more than 100,000 planning units) where importance scores cannot be calculated using other methods in a feasible period of time. This is because rarity weighted richness scores cannot (i) account for the cost of different planning units, (ii) account for multiple management zones, and (iii) identify truly irreplaceable planning units — unlike the replacement cost metric which does not suffer any of these limitations.
A numeric, matrix, data.frame,
terra::rast(), or sf::sf() object
containing the importance scores for each planning
unit in the solution. Specifically, the returned object is in the
same format as the planning unit data in x.
Broadly speaking, solution must be in the same format as
the planning unit data in x.
Further details on the correct format are listed separately
for each of the different planning unit data formats.
x has numeric planning unitsHere solution must be a
numeric vector with each element corresponding to a different planning
unit. It should have the same number of planning units as those
in x. Additionally, any planning units with missing
cost (NA) values should also have missing (NA) values in the
solution.
x has matrix planning unitsHere solution must be a
matrix vector with each row corresponding to a different planning
unit, and each column correspond to a different management zone.
It should have the same number of planning units and zones
as those in x. Additionally, any planning units with
missing cost (NA) values for a particular zone should also have a
missing (NA) values in solution.
x has terra::rast() planning unitsHere solution
be a terra::rast() object where different cells correspond
to different planning units and layers correspond to
a different management zones. It should have the same dimensionality
(rows, columns, layers), resolution, extent, and coordinate reference
system as the planning units in x. Additionally,
any planning units with missing cost (NA) values for a particular zone
should also have missing (NA) values in solution.
x has data.frame planning unitsHere solution must
be a data.frame with each column corresponding to a different zone,
each row corresponding to a different planning unit, and cell values
corresponding to the solution value. This means that if a data.frame
object containing the solution also contains additional columns, then
these columns will need to be subsetted prior to using this function
(see below for example with sf::sf() data).
Additionally, any planning units with missing cost
(NA) values for a particular zone should also have missing (NA)
values in solution.
x has sf::sf() planning unitsHere solution must be
a sf::sf() object with each column corresponding to a different
zone, each row corresponding to a different planning unit, and cell values
corresponding to the solution value. This means that if the
sf::sf() object containing the solution also contains additional
columns, then these columns will need to be subsetted prior to using this
function (see below for example).
Additionally, solution must also have the same
coordinate reference system as the planning unit data.
Furthermore, any planning units with missing cost
(NA) values for a particular zone should also have missing (NA)
values in solution.
Williams P, Gibbons D, Margules C, Rebelo A, Humphries C, and Pressey RL (1996) A comparison of richness hotspots, rarity hotspots and complementary areas for conserving diversity using British birds. Conservation Biology, 10: 155–174.
See importance for an overview of all functions for evaluating the importance of planning units selected in a solution.
Other functions for evaluating solution importance:
eval_ferrier_importance(),
eval_rank_importance(),
eval_replacement_importance()
# set seed for reproducibility
set.seed(600)
# load data
sim_pu_raster <- get_sim_pu_raster()
sim_pu_polygons <- get_sim_pu_polygons()
sim_features <- get_sim_features()
# create minimal problem with raster planning units
p1 <-
problem(sim_pu_raster, sim_features) %>%
add_min_set_objective() %>%
add_relative_targets(0.1) %>%
add_binary_decisions() %>%
add_default_solver(gap = 0, verbose = FALSE)
# solve problem
s1 <- solve(p1)
# print solution
print(s1)
# plot solution
plot(s1, main = "solution", axes = FALSE)
# calculate importance scores
rwr1 <- eval_rare_richness_importance(p1, s1)
# print importance scores
print(rwr1)
# plot importance scores
plot(rwr1, main = "rarity weighted richness", axes = FALSE)
# create minimal problem with polygon planning units
p2 <-
problem(sim_pu_polygons, sim_features, cost_column = "cost") %>%
add_min_set_objective() %>%
add_relative_targets(0.05) %>%
add_binary_decisions() %>%
add_default_solver(gap = 0, verbose = FALSE)
# solve problem
s2 <- solve(p2)
# print solution
print(s2)
# plot solution
plot(s2[, "solution_1"], main = "solution")
# calculate importance scores
rwr2 <- eval_rare_richness_importance(p2, s2[, "solution_1"])
# plot importance scores
plot(rwr2, main = "rarity weighted richness")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.